aboutsummaryrefslogtreecommitdiffstats
path: root/examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py')
-rw-r--r--examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py b/examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py
index 089c434e5..6c21a2a06 100644
--- a/examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py
+++ b/examples/widgets/richtext/syntaxhighlighter/syntaxhighlighter.py
@@ -40,14 +40,14 @@
##
#############################################################################
"""PySide2 port of the widgets/richtext/syntaxhighlighter example from Qt v5.x"""
import sys
import re
-from PySide2.QtCore import (QFile, Qt, QTextStream)
-from PySide2.QtGui import (QColor, QFont, QKeySequence, QSyntaxHighlighter,
+from PySide6.QtCore import (QFile, Qt, QTextStream)
+from PySide6.QtGui import (QColor, QFont, QKeySequence, QSyntaxHighlighter,
QTextCharFormat)
-from PySide2.QtWidgets import (QApplication, QFileDialog, QMainWindow,
+from PySide6.QtWidgets import (QApplication, QFileDialog, QMainWindow,
QPlainTextEdit)
import syntaxhighlighter_rc
@@ -40,14 +40,14 @@
##
#############################################################################
-"""PySide2 port of the widgets/richtext/syntaxhighlighter example from Qt v5.x"""
+"""PySide6 port of the widgets/richtext/syntaxhighlighter example from Qt v5.x"""
import sys
import re